@@ -32,8 +32,9 @@ functions support for sun3, sun4, 386 and 29k a.out files, to create a
 target jump vector for a specific target.
 
 This information is further split out into more specific files for each
-machine, including @code{sunos.c} - for sun3 and sun4 and
-@code{demo64} for a demonstration of a 64 bit a.out format.
+machine, including @code{sunos.c} for sun3 and sun4, @code{newsos3.c} for
+the Sony NEWS, and @code{demo64.c} for a demonstration of a 64 bit a.out
+format.
 
 The base file @code{aoutx.h} defines general mechanisms for reading
 and writing records to and from disk, and various other methods which
@@ -263,36 +264,23 @@ function just before returning, to handle any last-minute setup.
 */
  
 bfd_target *
-DEFUN(NAME(aout,some_aout_object_p),(abfd, callback_to_real_object_p),
+DEFUN(NAME(aout,some_aout_object_p),(abfd, execp, callback_to_real_object_p),
       bfd *abfd AND
+      struct internal_exec *execp AND
       bfd_target *(*callback_to_real_object_p) ())
 {
-  struct external_exec exec_bytes;
-  struct internal_exec *execp;
   struct container *rawptr;
 
-  if (bfd_seek (abfd, 0L, false) < 0) {
-    bfd_error = system_call_error;
-    return 0;
-  }
-
-  if (bfd_read ((PTR) &exec_bytes, 1, EXEC_BYTES_SIZE, abfd)
-      != EXEC_BYTES_SIZE) {
-    bfd_error = wrong_format;
-    return 0;
-  }
-
-  /* Use an intermediate variable for clarity */
   rawptr = (struct container *) bfd_zalloc (abfd, sizeof (struct container));
-
   if (rawptr == NULL) {
     bfd_error = no_memory;
     return 0;
   }
 
-  set_tdata (abfd, rawptr);
-  exec_hdr (abfd) = execp = &(rawptr->e);
-  NAME(aout,swap_exec_header_in)(abfd, &exec_bytes, execp);
+  set_tdata (abfd, &rawptr->a);
+  exec_hdr (abfd) = &rawptr->e;
+  *exec_hdr (abfd) = *execp;	/* Copy in the internal_exec struct */
+  execp = exec_hdr (abfd);	/* Switch to using the newly malloc'd one */
 
   /* Set the file flags */
   abfd->flags = NO_FLAGS;
@@ -313,12 +301,15 @@ DEFUN(NAME(aout,some_aout_object_p),(abfd, callback_to_real_object_p),
 
   /* Set the default architecture and machine type.  These can be
      overridden in the callback routine.  */
-  abfd->obj_arch = bfd_arch_unknown;
-  abfd->obj_machine = 0;
+
+  bfd_default_set_arch_mach(abfd, bfd_arch_unknown, 0);
 
   /* The default relocation entry size is that of traditional V7 Unix.  */
   obj_reloc_entry_size (abfd) = RELOC_STD_SIZE;
 
+  /* The default symbol entry size is that of traditional Unix. */
+  obj_symbol_entry_size (abfd) = EXTERNAL_NLIST_SIZE;
+
   /* create the sections.  This is raunchy, but bfd_close wants to reclaim
      them */
   obj_textsec (abfd) = (asection *)NULL;
@@ -336,17 +327,12 @@ DEFUN(NAME(aout,some_aout_object_p),(abfd, callback_to_real_object_p),
   obj_bsssec (abfd)->size = execp->a_bss;
   obj_textsec (abfd)->size = execp->a_text;
 
-  if (abfd->flags & D_PAGED) {
-    obj_textsec (abfd)->size -=  EXEC_BYTES_SIZE;
-  }
-    
-
   obj_textsec (abfd)->flags = (execp->a_trsize != 0 ?
-                               (SEC_ALLOC | SEC_LOAD | SEC_RELOC | SEC_HAS_CONTENTS) :
-                               (SEC_ALLOC | SEC_LOAD | SEC_HAS_CONTENTS));
+		       (SEC_ALLOC | SEC_LOAD | SEC_RELOC | SEC_HAS_CONTENTS) :
+		       (SEC_ALLOC | SEC_LOAD | SEC_HAS_CONTENTS));
   obj_datasec (abfd)->flags = (execp->a_drsize != 0 ?
-                               (SEC_ALLOC | SEC_LOAD | SEC_RELOC | SEC_HAS_CONTENTS) :
-                               (SEC_ALLOC | SEC_LOAD | SEC_HAS_CONTENTS));
+		       (SEC_ALLOC | SEC_LOAD | SEC_RELOC | SEC_HAS_CONTENTS) :
+		       (SEC_ALLOC | SEC_LOAD | SEC_HAS_CONTENTS));
   obj_bsssec (abfd)->flags = SEC_ALLOC;
 
 #ifdef THIS_IS_ONLY_DOCUMENTATION
@@ -395,6 +381,10 @@ DEFUN(NAME(aout,some_aout_object_p),(abfd, callback_to_real_object_p),
     obj_reloc_entry_size (abfd) = RELOC_STD_SIZE;
   }
 
+  adata(abfd)->page_size = PAGE_SIZE;
+  adata(abfd)->segment_size = SEGMENT_SIZE;
+  adata(abfd)->exec_bytes_size = EXEC_BYTES_SIZE;
+
   return abfd->xvec;
 
   /* The architecture is encoded in various ways in various a.out variants,
@@ -505,6 +495,7 @@ DEFUN(NAME(aout,machine_type),(arch, machine),
   return arch_flags;
 }
 
+
 /*doc*
 *i aout_<size>_set_arch_mach
 
@@ -524,8 +515,7 @@ DEFUN(NAME(aout,set_arch_mach),(abfd, arch, machine),
       enum bfd_architecture arch AND
       unsigned long machine)
 {
-  abfd->obj_arch = arch;
-  abfd->obj_machine = machine;
+  bfd_default_set_arch_mach(abfd, arch, machine);
   if (arch != bfd_arch_unknown &&
       NAME(aout,machine_type) (arch, machine) == M_UNKNOWN)
     return false;		/* We can't represent this type */
@@ -533,17 +523,17 @@ DEFUN(NAME(aout,set_arch_mach),(abfd, arch, machine),
 }
 
 /*doc*
-*i aout_<size>new_section_hook
-
-Called by the BFD in response to a @code{bfd_make_section} request.
-*; PROTO(boolean, aout_<size>_new_section_hook,
-         (bfd *abfd,
-	  asection *newsect));
+  *i aout_<size>new_section_hook
+  
+  Called by the BFD in response to a @code{bfd_make_section} request.
+  *; PROTO(boolean, aout_<size>_new_section_hook,
+	   (bfd *abfd,
+	    asection *newsect));
 */
 boolean
-DEFUN(NAME(aout,new_section_hook),(abfd, newsect),
-      bfd *abfd AND
-      asection *newsect)
+  DEFUN(NAME(aout,new_section_hook),(abfd, newsect),
+	bfd *abfd AND
+	asection *newsect)
 {
   /* align to double at least */
   newsect->alignment_power = 3;
@@ -570,50 +560,80 @@ DEFUN(NAME(aout,new_section_hook),(abfd, newsect),
 }
 
 boolean
-DEFUN(NAME(aout,set_section_contents),(abfd, section, location, offset, count),
-      bfd *abfd AND
-      sec_ptr section AND
-      PTR location AND
-      file_ptr offset AND
-      bfd_size_type count)
+  DEFUN(NAME(aout,set_section_contents),(abfd, section, location, offset, count),
+	bfd *abfd AND
+	sec_ptr section AND
+	PTR location AND
+	file_ptr offset AND
+	bfd_size_type count)
 {
+  file_ptr text_end;
+  bfd_size_type text_header_size; /* exec_bytes_size if if included in 
+      text size. */
+  bfd_size_type text_size;
   if (abfd->output_has_begun == false)
-    {				/* set by bfd.c handler */
-      switch (abfd->direction)
-	{
-	  case read_direction:
-	  case no_direction:
-	    bfd_error = invalid_operation;
-	    return false;
-
-	  case both_direction:
-	    break;
-
-	  case write_direction:
-	    if ((obj_textsec (abfd) == NULL) || (obj_datasec (abfd) == NULL)) 
+      {				/* set by bfd.c handler */
+	switch (abfd->direction)
+	    {
+	    case read_direction:
+	    case no_direction:
+	      bfd_error = invalid_operation;
+	      return false;
+		
+	    case both_direction:
+	      break;
+		
+	    case write_direction:
+	      if ((obj_textsec (abfd) == NULL) || (obj_datasec (abfd) == NULL)) 
+		  {
+		    bfd_error = invalid_operation;
+		    return false;
+		  }
+	      obj_textsec(abfd)->size =
+		  align_power(obj_textsec(abfd)->size,
+			      obj_textsec(abfd)->alignment_power);
+	      text_size = obj_textsec (abfd)->size;
+	      /* Rule (heuristic) for when to pad to a new page.
+	       * Note that there are (at least) two ways demand-paged
+	       * (ZMAGIC) files have been handled.  Most Berkeley-based systems
+	       * start the text segment at (PAGE_SIZE).  However, newer
+	       * versions of SUNOS start the text segment right after the
+	       * exec header; the latter is counted in the text segment size,
+	       * and is paged in by the kernel with the rest of the text. */
+	      if (!(abfd->flags & D_PAGED))
+		{ /* Not demand-paged. */
+		  obj_textsec(abfd)->filepos = adata(abfd)->exec_bytes_size;
+	        }
+	      else if (obj_textsec(abfd)->vma % adata(abfd)->page_size
+		    < adata(abfd)->exec_bytes_size)
+		{ /* Old-style demand-paged. */
+		  obj_textsec(abfd)->filepos = adata(abfd)->page_size;
+	        }
+	      else
+		{ /* Sunos-style demand-paged. */
+		  obj_textsec(abfd)->filepos = adata(abfd)->exec_bytes_size;
+		  text_size += adata(abfd)->exec_bytes_size;
+	        }
+	      text_end = obj_textsec(abfd)->size + obj_textsec(abfd)->filepos;
+	      if (abfd->flags & (D_PAGED|WP_TEXT))
 		{
-		  bfd_error = invalid_operation;
-		  return false;
+		  bfd_size_type text_pad =
+		      ALIGN(text_size, adata(abfd)->segment_size) - text_size;
+	          text_end += text_pad;
+		  obj_textsec(abfd)->size += text_pad;
 		}
-	    /*if (abfd->flags & D_PAGED) {	  
-	      obj_textsec(abfd)->filepos = 0;
+	      obj_datasec(abfd)->filepos = text_end;
+	      obj_datasec(abfd)->size =
+		  align_power(obj_datasec(abfd)->size,
+			      obj_datasec(abfd)->alignment_power);
 	    }
-	    else*/ {
-	      obj_textsec(abfd)->filepos = EXEC_BYTES_SIZE;
-	    }
-	    obj_textsec(abfd)->size = align_power(obj_textsec(abfd)->size,
-						  obj_textsec(abfd)->alignment_power);
-	    obj_datasec(abfd)->filepos =  obj_textsec (abfd)->size + EXEC_BYTES_SIZE;
-	    obj_datasec(abfd)->size = align_power(obj_datasec(abfd)->size,
-						obj_datasec(abfd)->alignment_power);
-	}
-    }
+      }
 
   /* regardless, once we know what we're doing, we might as well get going */
   if (section != obj_bsssec(abfd)) 
       {
 	bfd_seek (abfd, section->filepos + offset, SEEK_SET);
-	  
+    
 	if (count) {
 	  return (bfd_write ((PTR)location, 1, count, abfd) == count) ?
 	    true : false;
@@ -626,116 +646,116 @@ DEFUN(NAME(aout,set_section_contents),(abfd, section, location, offset, count),
 /* Classify stabs symbols */
 
 #define sym_in_text_section(sym) \
-(((sym)->type  & (N_ABS | N_TEXT | N_DATA | N_BSS))== N_TEXT)
+  (((sym)->type  & (N_ABS | N_TEXT | N_DATA | N_BSS))== N_TEXT)
 
 #define sym_in_data_section(sym) \
-(((sym)->type  & (N_ABS | N_TEXT | N_DATA | N_BSS))== N_DATA)
+  (((sym)->type  & (N_ABS | N_TEXT | N_DATA | N_BSS))== N_DATA)
 
 #define sym_in_bss_section(sym) \
-(((sym)->type  & (N_ABS | N_TEXT | N_DATA | N_BSS))== N_BSS)
+  (((sym)->type  & (N_ABS | N_TEXT | N_DATA | N_BSS))== N_BSS)
 
 /* Symbol is undefined if type is N_UNDF|N_EXT and if it has
-zero in the "value" field.  Nonzeroes there are fortrancommon
-symbols.  */
+  zero in the "value" field.  Nonzeroes there are fortrancommon
+  symbols.  */
 #define sym_is_undefined(sym) \
-((sym)->type == (N_UNDF | N_EXT) && (sym)->symbol.value == 0)
+  ((sym)->type == (N_UNDF | N_EXT) && (sym)->symbol.value == 0)
 
 /* Symbol is a global definition if N_EXT is on and if it has
-a nonzero type field.  */
+  a nonzero type field.  */
 #define sym_is_global_defn(sym) \
-(((sym)->type & N_EXT) && (sym)->type & N_TYPE)
+  (((sym)->type & N_EXT) && (sym)->type & N_TYPE)
 
 /* Symbol is debugger info if any bits outside N_TYPE or N_EXT
-are on.  */
+  are on.  */
 #define sym_is_debugger_info(sym) \
-((sym)->type & ~(N_EXT | N_TYPE))
+  ((sym)->type & ~(N_EXT | N_TYPE))
 
 #define sym_is_fortrancommon(sym)       \
-(((sym)->type == (N_EXT)) && (sym)->symbol.value != 0)
+  (((sym)->type == (N_EXT)) && (sym)->symbol.value != 0)
 
 /* Symbol is absolute if it has N_ABS set */
 #define sym_is_absolute(sym) \
-(((sym)->type  & N_TYPE)== N_ABS)
+  (((sym)->type  & N_TYPE)== N_ABS)
 
 
 #define sym_is_indirect(sym) \
-(((sym)->type & N_ABS)== N_ABS)
+  (((sym)->type & N_ABS)== N_ABS)
 
 /* Only in their own functions for ease of debugging; when sym flags have
-stabilised these should be inlined into their (single) caller */
-
+  stabilised these should be inlined into their (single) caller */
+  
 static void
 DEFUN(translate_from_native_sym_flags,(sym_pointer, cache_ptr, abfd),
-      struct external_nlist *sym_pointer AND
-      aout_symbol_type *cache_ptr AND
-      bfd *abfd)
-  {
-    switch (cache_ptr->type & N_TYPE) {
-    case N_SETA:
-    case N_SETT:
-    case N_SETD:
-    case N_SETB:
-	{
-	  char *copy = bfd_alloc(abfd, strlen(cache_ptr->symbol.name)+1);
-	  asection *section ;
-	  arelent_chain *reloc = (arelent_chain *)bfd_alloc(abfd, sizeof(arelent_chain));
-	  strcpy(copy, cache_ptr->symbol.name);
-	  section = bfd_make_section(abfd,copy);
-	  switch ( (cache_ptr->type  & N_TYPE) ) {
-	  case N_SETA:
-	    section->flags = SEC_CONSTRUCTOR;
-	    reloc->relent.section =  (asection *)NULL;
-	    cache_ptr->symbol.section = (asection *)NULL;
-	    break;
-	  case N_SETT:
-	    section->flags = SEC_CONSTRUCTOR_TEXT;
-	    reloc->relent.section = (asection *)obj_textsec(abfd);
-	    cache_ptr->symbol.value -= reloc->relent.section->vma;
-	    break;
-	  case N_SETD:
-	    section->flags = SEC_CONSTRUCTOR_DATA;
-	    reloc->relent.section = (asection *)obj_datasec(abfd);
-	    cache_ptr->symbol.value -= reloc->relent.section->vma;
-	    break;
-	  case N_SETB:
-	    section->flags = SEC_CONSTRUCTOR_BSS;
-	    reloc->relent.section = (asection *)obj_bsssec(abfd);
-	    cache_ptr->symbol.value -= reloc->relent.section->vma;
-	    break;
-	  }
-	  cache_ptr->symbol.section = reloc->relent.section;
-	  reloc->relent.addend = cache_ptr->symbol.value ;
-	  
-	  /* We modify the symbol to belong to a section depending upon the
-	    name of the symbol - probably __CTOR__ or __DTOR__ but we don't
-	      really care, and add to the size of the section to contain a
-		pointer to the symbol. Build a reloc entry to relocate to this
-		  symbol attached to this section.  */
-	  
-	  
-	  section->reloc_count++;
-	  section->alignment_power = 2;
-	  reloc->relent.sym_ptr_ptr = (asymbol **)NULL;
-	  reloc->next = section->constructor_chain;
-	  section->constructor_chain = reloc;
-	  reloc->relent.address = section->size;
-	  section->size += sizeof(int *);
-	  
-	  reloc->relent.howto = howto_table_ext +CTOR_TABLE_RELOC_IDX;
-	  cache_ptr->symbol.flags |=  BSF_DEBUGGING  | BSF_CONSTRUCTOR;
+struct external_nlist *sym_pointer AND
+aout_symbol_type *cache_ptr AND
+bfd *abfd)
+{
+  switch (cache_ptr->type & N_TYPE) {
+  case N_SETA:
+  case N_SETT:
+  case N_SETD:
+  case N_SETB:
+      {
+	char *copy = bfd_alloc(abfd, strlen(cache_ptr->symbol.name)+1);
+	asection *section ;
+	arelent_chain *reloc = (arelent_chain *)bfd_alloc(abfd, sizeof(arelent_chain));
+	strcpy(copy, cache_ptr->symbol.name);
+	section = bfd_make_section(abfd,copy);
+	switch ( (cache_ptr->type  & N_TYPE) ) {
+	case N_SETA:
+	  section->flags = SEC_CONSTRUCTOR;
+	  reloc->relent.section =  (asection *)NULL;
+	  cache_ptr->symbol.section = (asection *)NULL;
+	  break;
+	case N_SETT:
+	  section->flags = SEC_CONSTRUCTOR_TEXT;
+	  reloc->relent.section = (asection *)obj_textsec(abfd);
+	  cache_ptr->symbol.value -= reloc->relent.section->vma;
+	  break;
+	case N_SETD:
+	  section->flags = SEC_CONSTRUCTOR_DATA;
+	  reloc->relent.section = (asection *)obj_datasec(abfd);
+	  cache_ptr->symbol.value -= reloc->relent.section->vma;
+	  break;
+	case N_SETB:
+	  section->flags = SEC_CONSTRUCTOR_BSS;
+	  reloc->relent.section = (asection *)obj_bsssec(abfd);
+	  cache_ptr->symbol.value -= reloc->relent.section->vma;
+	  break;
 	}
-	break;
+	cache_ptr->symbol.section = reloc->relent.section;
+	reloc->relent.addend = cache_ptr->symbol.value ;
+	  
+	/* We modify the symbol to belong to a section depending upon the
+	   name of the symbol - probably __CTOR__ or __DTOR__ but we don't
+	   really care, and add to the size of the section to contain a
+	   pointer to the symbol. Build a reloc entry to relocate to this
+	   symbol attached to this section.  */
+	  
+	  
+	section->reloc_count++;
+	section->alignment_power = 2;
+	reloc->relent.sym_ptr_ptr = (asymbol **)NULL;
+	reloc->next = section->constructor_chain;
+	section->constructor_chain = reloc;
+	reloc->relent.address = section->size;
+	section->size += sizeof(int *);
+	  
+	reloc->relent.howto = howto_table_ext +CTOR_TABLE_RELOC_IDX;
+	cache_ptr->symbol.flags |=  BSF_DEBUGGING  | BSF_CONSTRUCTOR;
+      }
+    break;
   default:
     if (cache_ptr->type ==  N_WARNING) 
 	{
-      /* This symbol is the text of a warning message, the next symbol
-	 is the symbol to associate the warning with */
-      cache_ptr->symbol.flags = BSF_DEBUGGING | BSF_WARNING;
-      cache_ptr->symbol.value = (bfd_vma)((cache_ptr+1));
-      /* We furgle with the next symbol in place. We don't want it to be undefined, we'll trample the type */
-      (sym_pointer+1)->e_type[0] = 0xff;
-      break;
-    }
+	  /* This symbol is the text of a warning message, the next symbol
+	     is the symbol to associate the warning with */
+	  cache_ptr->symbol.flags = BSF_DEBUGGING | BSF_WARNING;
+	  cache_ptr->symbol.value = (bfd_vma)((cache_ptr+1));
+	  /* We furgle with the next symbol in place. We don't want it to be undefined, we'll trample the type */
+	  (sym_pointer+1)->e_type[0] = 0xff;
+	  break;
+	}
     if ((cache_ptr->type | N_EXT) == (N_INDR | N_EXT)) {
       /* Two symbols in a row for an INDR message. The first symbol
 	 contains the name we will match, the second symbol contains the
@@ -884,90 +904,90 @@ hold them all plus all the cached symbol entries. */
 asymbol *
 DEFUN(NAME(aout,make_empty_symbol),(abfd),
       bfd *abfd)
-  {
-    aout_symbol_type  *new =
-      (aout_symbol_type *)bfd_zalloc (abfd, sizeof (aout_symbol_type));
-    new->symbol.the_bfd = abfd;
+{
+  aout_symbol_type  *new =
+    (aout_symbol_type *)bfd_zalloc (abfd, sizeof (aout_symbol_type));
+  new->symbol.the_bfd = abfd;
     
-    return &new->symbol;
-  }
+  return &new->symbol;
+}
 
 boolean
 DEFUN(NAME(aout,slurp_symbol_table),(abfd),
       bfd *abfd)
-  {
-    bfd_size_type symbol_size;
-    bfd_size_type string_size;
-    unsigned char string_chars[BYTES_IN_WORD];
-    struct external_nlist *syms;
-    char *strings;
-    aout_symbol_type *cached;
+{
+  bfd_size_type symbol_size;
+  bfd_size_type string_size;
+  unsigned char string_chars[BYTES_IN_WORD];
+  struct external_nlist *syms;
+  char *strings;
+  aout_symbol_type *cached;
     
-    /* If there's no work to be done, don't do any */
-    if (obj_aout_symbols (abfd) != (aout_symbol_type *)NULL) return true;
-    symbol_size = exec_hdr(abfd)->a_syms;
-    if (symbol_size == 0) {
-      bfd_error = no_symbols;
-      return false;
-    }
-    
-    bfd_seek (abfd, obj_str_filepos (abfd), SEEK_SET);
-    if (bfd_read ((PTR)string_chars, BYTES_IN_WORD, 1, abfd) != BYTES_IN_WORD)
-      return false;
-    string_size = GET_WORD (abfd, string_chars);
-    
-    strings =(char *) bfd_alloc(abfd, string_size + 1);
-    cached = (aout_symbol_type *)
-      bfd_zalloc(abfd, (bfd_size_type)(bfd_get_symcount (abfd) * sizeof(aout_symbol_type)));
-
-    /* malloc this, so we can free it if simply. The symbol caching
-       might want to allocate onto the bfd's obstack  */
-    syms = (struct external_nlist *) malloc(symbol_size);
-    bfd_seek (abfd, obj_sym_filepos (abfd), SEEK_SET);
-    if (bfd_read ((PTR)syms, 1, symbol_size, abfd) != symbol_size) {
-    bailout:
-      if (syms) 	free (syms);
-      if (cached)	bfd_release (abfd, cached);
-      if (strings)bfd_release (abfd, strings);
-      return false;
-    }
-    
-    bfd_seek (abfd, obj_str_filepos (abfd), SEEK_SET);
-    if (bfd_read ((PTR)strings, 1, string_size, abfd) != string_size) {
-      goto bailout;
-    }
-    
-    /* OK, now walk the new symtable, cacheing symbol properties */
-      {
-	register struct external_nlist *sym_pointer;
-	register struct external_nlist *sym_end = syms + bfd_get_symcount (abfd);
-	register aout_symbol_type *cache_ptr = cached;
-	
-	/* Run through table and copy values */
-	for (sym_pointer = syms, cache_ptr = cached;
-	     sym_pointer < sym_end; sym_pointer++, cache_ptr++) 
-	    {
-	      bfd_vma x = GET_WORD(abfd, sym_pointer->e_strx);
-	      cache_ptr->symbol.the_bfd = abfd;
-	      if (x)
-		cache_ptr->symbol.name = x + strings;
-	      else
-		cache_ptr->symbol.name = (char *)NULL;
-	      
-	      cache_ptr->symbol.value = GET_SWORD(abfd,  sym_pointer->e_value);
-	      cache_ptr->desc = bfd_get_16(abfd, sym_pointer->e_desc);
-	      cache_ptr->other =bfd_get_8(abfd, sym_pointer->e_other);
-	      cache_ptr->type = bfd_get_8(abfd,  sym_pointer->e_type);
-	      cache_ptr->symbol.udata = 0;
-	      translate_from_native_sym_flags (sym_pointer, cache_ptr, abfd);
-	    }
-      }
-    
-    obj_aout_symbols (abfd) =  cached;
-    free((PTR)syms);
-    
-    return true;
+  /* If there's no work to be done, don't do any */
+  if (obj_aout_symbols (abfd) != (aout_symbol_type *)NULL) return true;
+  symbol_size = exec_hdr(abfd)->a_syms;
+  if (symbol_size == 0) {
+    bfd_error = no_symbols;
+    return false;
   }
+    
+  bfd_seek (abfd, obj_str_filepos (abfd), SEEK_SET);
+  if (bfd_read ((PTR)string_chars, BYTES_IN_WORD, 1, abfd) != BYTES_IN_WORD)
+    return false;
+  string_size = GET_WORD (abfd, string_chars);
+    
+  strings =(char *) bfd_alloc(abfd, string_size + 1);
+  cached = (aout_symbol_type *)
+    bfd_zalloc(abfd, (bfd_size_type)(bfd_get_symcount (abfd) * sizeof(aout_symbol_type)));
+
+  /* malloc this, so we can free it if simply. The symbol caching
+     might want to allocate onto the bfd's obstack  */
+  syms = (struct external_nlist *) malloc(symbol_size);
+  bfd_seek (abfd, obj_sym_filepos (abfd), SEEK_SET);
+  if (bfd_read ((PTR)syms, 1, symbol_size, abfd) != symbol_size) {
+  bailout:
+    if (syms) 	free (syms);
+    if (cached)	bfd_release (abfd, cached);
+    if (strings)bfd_release (abfd, strings);
+    return false;
+  }
+    
+  bfd_seek (abfd, obj_str_filepos (abfd), SEEK_SET);
+  if (bfd_read ((PTR)strings, 1, string_size, abfd) != string_size) {
+    goto bailout;
+  }
+    
+  /* OK, now walk the new symtable, cacheing symbol properties */
+    {
+      register struct external_nlist *sym_pointer;
+      register struct external_nlist *sym_end = syms + bfd_get_symcount (abfd);
+      register aout_symbol_type *cache_ptr = cached;
+	
+      /* Run through table and copy values */
+      for (sym_pointer = syms, cache_ptr = cached;
+	   sym_pointer < sym_end; sym_pointer++, cache_ptr++) 
+	  {
+	    bfd_vma x = GET_WORD(abfd, sym_pointer->e_strx);
+	    cache_ptr->symbol.the_bfd = abfd;
+	    if (x)
+	      cache_ptr->symbol.name = x + strings;
+	    else
+	      cache_ptr->symbol.name = (char *)NULL;
+	      
+	    cache_ptr->symbol.value = GET_SWORD(abfd,  sym_pointer->e_value);
+	    cache_ptr->desc = bfd_get_16(abfd, sym_pointer->e_desc);
+	    cache_ptr->other =bfd_get_8(abfd, sym_pointer->e_other);
+	    cache_ptr->type = bfd_get_8(abfd,  sym_pointer->e_type);
+	    cache_ptr->symbol.udata = 0;
+	    translate_from_native_sym_flags (sym_pointer, cache_ptr, abfd);
+	  }
+    }
+    
+  obj_aout_symbols (abfd) =  cached;
+  free((PTR)syms);
+    
+  return true;
+}
 
 
 void
@@ -983,7 +1003,6 @@ DEFUN(NAME(aout,write_syms),(abfd),
       asymbol *g = generic[count];
       struct external_nlist nsp;
       
-      
       if (g->name) {
 	unsigned int length = strlen(g->name) +1;
 	PUT_WORD  (abfd, stindex, (unsigned char *)nsp.e_strx);
@@ -1005,18 +1024,14 @@ DEFUN(NAME(aout,write_syms),(abfd),
 	    bfd_h_put_8(abfd, 0,  nsp.e_other);
 	    bfd_h_put_8(abfd, 0,  nsp.e_type);
 	  }
-      
-      
-      
+
       translate_to_native_sym_flags (&nsp, g, abfd);
-      
-      bfd_write((PTR)&nsp,1,EXTERNAL_LIST_SIZE, abfd);
+
+      bfd_write((PTR)&nsp,1,EXTERNAL_NLIST_SIZE, abfd);
     }
     
-    
     /* Now output the strings.  Be sure to put string length into correct
-      * byte ordering before writing it.
-	*/
+       byte ordering before writing it.  */
       {
 	char buffer[BYTES_IN_WORD];
 	PUT_WORD  (abfd, stindex, (unsigned char *)buffer);
@@ -1569,32 +1584,34 @@ DEFUN(NAME(aout,print_symbol),(ignore_abfd, afile, symbol, how),
       bfd *ignore_abfd AND
       PTR afile AND
       asymbol *symbol AND
-      bfd_print_symbol_enum_type how)
+      bfd_print_symbol_type how)
 {
   FILE *file = (FILE *)afile;
 
   switch (how) {
-  case bfd_print_symbol_name_enum:
-    fprintf(file,"%s", symbol->name);
+  case bfd_print_symbol_name:
+    if (symbol->name)
+      fprintf(file,"%s", symbol->name);
     break;
-  case bfd_print_symbol_type_enum:
+  case bfd_print_symbol_more:
     fprintf(file,"%4x %2x %2x",(unsigned)(aout_symbol(symbol)->desc & 0xffff),
 	    (unsigned)(aout_symbol(symbol)->other & 0xff),
 	    (unsigned)(aout_symbol(symbol)->type));
     break;
-  case bfd_print_symbol_all_enum:
+  case bfd_print_symbol_all:
     {
    CONST char *section_name = symbol->section == (asection *)NULL ?
 	"*abs" : symbol->section->name;
 
       bfd_print_symbol_vandf((PTR)file,symbol);
 
-      fprintf(file," %-5s %04x %02x %02x %s",
+      fprintf(file," %-5s %04x %02x %02x",
 	      section_name,
 	      (unsigned)(aout_symbol(symbol)->desc & 0xffff),
 	      (unsigned)(aout_symbol(symbol)->other & 0xff),
-	      (unsigned)(aout_symbol(symbol)->type  & 0xff),
-	      symbol->name);
+	      (unsigned)(aout_symbol(symbol)->type  & 0xff));
+      if (symbol->name)
+        fprintf(file," %s", symbol->name);
     }
     break;
   }
@@ -1667,7 +1684,7 @@ DEFUN(NAME(aout,find_nearest_line),(abfd,
 	    buffer[sizeof(buffer)-1] = 0;
 	    /* Have to remove : stuff */
 	    p = strchr(buffer,':');
-	    if (p != NULL) { *p = NULL; }
+	    if (p != NULL) { *p = '\0'; }
 	    *functionname_ptr = buffer;
 	    return true;
 
@@ -1683,9 +1700,9 @@ DEFUN(NAME(aout,find_nearest_line),(abfd,
 }
 
 int 
-DEFUN(NAME(aout,sizeof_headers),(ignore_abfd, execable),
-      bfd *ignore_abfd AND
+DEFUN(NAME(aout,sizeof_headers),(abfd, execable),
+      bfd *abfd AND
       boolean execable)
 {
-  return EXEC_BYTES_SIZE;
+  return adata(abfd)->exec_bytes_size;
 }
