@@ -1,3 +1,4 @@
+
 /* libbfd.h -- Declarations used by bfd library *implementation*.
    (This include file is not for users of the library.)
    Copyright (C) 1990-1991 Free Software Foundation, Inc.
@@ -19,7 +20,11 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
-/* $Id: libbfd.h,v 1.19 1991/08/21 21:37:36 pesch Exp $ */
+
+/* Align an address upward to a boundary, expressed as a number of bytes.
+   E.g. align to an 8-byte boundary with argument of 8.  */
+#define ALIGN(this, boundary) \
+  ((( (this) + ((boundary) -1)) & (~((boundary)-1))))
 
 /* If you want to read and write large blocks, you might want to do it
    in quanta of this amount */
@@ -72,7 +77,7 @@ PROTO(PTR, bfd_alloc_finish,(bfd *abfd));
 
 
 PROTO (bfd_size_type, bfd_read, (PTR ptr, bfd_size_type size, bfd_size_type nitems, bfd *abfd));
-PROTO (bfd_size_type, bfd_write, (PTR ptr, bfd_size_type size, bfd_size_type nitems, bfd *abfd));
+PROTO (bfd_size_type, bfd_write, (CONST PTR ptr, bfd_size_type size, bfd_size_type nitems, bfd *abfd));
 
 
 
@@ -140,7 +145,12 @@ PROTO (bfd *, bfd_generic_openr_next_archived_file, (bfd *archive,
 PROTO(int, bfd_generic_stat_arch_elt, (bfd *, struct stat *));
 
 PROTO(boolean, bfd_generic_get_section_contents,
-      (bfd *abfd, sec_ptr section, PTR location, file_ptr offset, bfd_size_type count));
+      (bfd *abfd, sec_ptr section, PTR location, file_ptr offset,
+       bfd_size_type count));
+
+PROTO(boolean, bfd_generic_set_section_contents,
+      (bfd *abfd, sec_ptr section, PTR location, file_ptr offset,
+       bfd_size_type count));
 
 /* Macros to tell if bfds are read or write enabled.
 
@@ -179,6 +189,20 @@ extern bfd *bfd_last_cache;
 
 /* THE FOLLOWING IS EXTRACTED FROM THE SOURCE*/
 
+/*:init.c*/
+/* bfd_check_init
+
+This routine is called before any other bfd function using initialized
+data is used to ensure that the structures have been initialized.
+Soon this function will go away, and the bfd library will assume that
+bfd_init has been called.
+*/
+
+ void EXFUN(bfd_check_init,(void));
+
+/*
+*/
+
 /*:libbfd.c*/
 /* *i bfd_log2
 Return the log base 2 of the value supplied, rounded up. eg an arg
@@ -259,3 +283,69 @@ one first, to avoid running out of file descriptors.
 
 /*:reloc.c*/
 
+/*:cpu-h8300.c*/
+
+/*:cpu-i960.c*/
+
+/*:cpu-empty.c*/
+
+/*:archures.c*/
+/* bfd_default_arch_struct
+
+What bfds are seeded with 
+*/
+
+extern bfd_arch_info_type bfd_default_arch_struct;
+
+/*
+ bfd_default_set_arch_mach
+
+Set the architecture and machine type in a bfd. This finds the correct
+pointer to structure and inserts it into the arch_info pointer. 
+*/
+
+  boolean EXFUN(bfd_default_set_arch_mach,(bfd *abfd,
+          enum bfd_architecture arch,
+	 unsigned long mach));
+
+/*
+
+This routine initializes the architecture dispatch table by calling
+all installed architecture packages and getting them to poke around.
+*/
+
+ PROTO(void, bfd_arch_init,(void));
+
+/*
+
+ bfd_arch_linkin
+
+Link the provided arch info structure into the list
+*/
+
+ void EXFUN(bfd_arch_linkin,(bfd_arch_info_type *));
+
+/*
+
+ bfd_default_compatible
+
+The default function for testing for compatibility 
+*/
+
+ CONST bfd_arch_info_type *EXFUN(bfd_default_compatible,
+     (CONST bfd_arch_info_type *a,
+     CONST bfd_arch_info_type *b));
+
+/*
+
+ bfd_default_scan
+The default function for working out whether this is an architecture
+hit and a machine hit 
+*/
+
+ boolean EXFUN(bfd_default_scan,(CONST struct bfd_arch_info *, CONST char *));
+
+/*
+*/
+
+
