@@ -60,7 +60,7 @@ static struct tchars tc_inferior;
 static struct tchars tc_ours;
 #endif
 
-#ifdef TIOCGLTC
+#if defined(TIOCGLTC) && !defined(TIOCGLTC_BROKEN)
 static struct ltchars ltc_inferior;
 static struct ltchars ltc_ours;
 #endif
@@ -105,7 +105,7 @@ terminal_init_inferior ()
   tc_inferior = tc_ours;
 #endif
 
-#ifdef TIOCGLTC
+#if defined(TIOCGLTC) && !defined(TIOCGLTC_BROKEN)
   ltc_inferior = ltc_ours;
 #endif
 
@@ -135,7 +135,7 @@ terminal_inferior ()
 #if defined(TIOCGETC) && !defined(TIOCGETC_BROKEN)
       ioctl (0, TIOCSETC, &tc_inferior);
 #endif
-#ifdef TIOCGLTC
+#if defined(TIOCGLTC) && !defined(TIOCGLTC_BROKEN)
       ioctl (0, TIOCSLTC, &ltc_inferior);
 #endif
 #ifdef TIOCLGET
@@ -215,7 +215,7 @@ terminal_ours_1 (output_only)
 #if defined(TIOCGETC) && !defined(TIOCGETC_BROKEN)
       ioctl (0, TIOCGETC, &tc_inferior);
 #endif
-#ifdef TIOCGLTC
+#if defined(TIOCGLTC) && !defined(TIOCGLTC_BROKEN)
       ioctl (0, TIOCGLTC, &ltc_inferior);
 #endif
 #ifdef TIOCLGET
@@ -240,7 +240,7 @@ terminal_ours_1 (output_only)
 #if defined(TIOCGETC) && !defined(TIOCGETC_BROKEN)
   ioctl (0, TIOCSETC, &tc_ours);
 #endif
-#ifdef TIOCGLTC
+#if defined(TIOCGLTC) && !defined(TIOCGLTC_BROKEN)
   ioctl (0, TIOCSLTC, &ltc_ours);
 #endif
 #ifdef TIOCLGET
@@ -298,7 +298,7 @@ child_terminal_info (args, from_tty)
   printf_filtered ("\n");
 #endif
 
-#ifdef TIOCGLTC
+#if defined(TIOCGLTC) && !defined(TIOCGLTC_BROKEN)
   printf_filtered ("ltchars: ");
   for (i = 0; i < (int)sizeof (struct ltchars); i++)
     printf_filtered ("0x%x ", ((char *)&ltc_inferior)[i]);
@@ -488,7 +488,7 @@ Report which ones can be written.");
 #if defined(TIOCGETC) && !defined(TIOCGETC_BROKEN)
   ioctl (0, TIOCGETC, &tc_ours);
 #endif
-#ifdef TIOCGLTC
+#if defined(TIOCGLTC) && !defined(TIOCGLTC_BROKEN)
   ioctl (0, TIOCGLTC, &ltc_ours);
 #endif
 #ifdef TIOCLGET
