@@ -23,25 +23,35 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #define HOST_BYTE_ORDER LITTLE_ENDIAN
 #endif
 
-/* wait.h */
-#define HAVE_WAIT_STRUCT
-
 /* Get rid of any system-imposed stack limit if possible */
 
 #define	SET_STACK_LIMIT_HUGE
 
 /* This WOULD BE the amount to subtract from u.u_ar0
    to get the offset in the core file of the register values.
-   But Mips' ptrace works on regnums, not displacements */
+   But Mips' ptrace works on regnums, not displacements.  So since
+   REGISTER_U_ADDR is called for both core files and ptrace, use
+   BLOCKEND as a flag:  0 for core files, 1 for ptrace.  What a
+   kludge.  */
 
-#define KERNEL_U_ADDR (int)u.u_ar0
+#define KERNEL_U_ADDR (int)reg_ptr	/* Magic, causes a zero blockend */
+
+#define REGISTER_U_ADDR(addr, blockend, regno) 		\
+   if (blockend == 0) {					\
+	if (regno < 38) addr = (NBPG*UPAGES) + (regno - 38)*sizeof(int);\
+	else addr = 0; /* ..somewhere in the pcb */	\
+   } else if (regno < 32) addr = regno;			\
+   else if (regno == PC_REGNUM) addr = 96;		\
+   else if (regno == 36) addr = 97;			\
+   else if (regno == HI_REGNUM) addr = 98;		\
+   else if (regno == LO_REGNUM) addr = 99;		\
+   else if (regno == FCRCS_REGNUM) addr = 100;		\
+   else if (regno == FCRIR_REGNUM) addr = 101;		\
+   else if (regno >= FP0_REGNUM) addr = regno - (FP0_REGNUM-32);\
+   else addr = 0;
 
 /* Override copies of {fetch,store}_inferior_registers in infptrace.c.  */
 #define FETCH_INFERIOR_REGISTERS
 
 /* Kernel is a bit tenacious about sharing text segments, disallowing bpts.  */
 #define	ONE_PROCESS_WRITETEXT
-
-/* Interface definitions for kernel debugger KDB */
-
-/* I am not going to pretend I've done anything about this */
